#ifndef TIMELINELISTMODEL_H
#define TIMELINELISTMODEL_H

#include <QAbstractListModel>
#include <QList>
#include <QtQmlIntegration>

class TimelineListModel : public QAbstractListModel
{
    Q_OBJECT
    QML_ELEMENT
    Q_PROPERTY(QDate fromDate READ fromDate WRITE setFromDate NOTIFY fromDateChanged REQUIRED)
    Q_PROPERTY(QDate toDate READ toDate WRITE setToDate NOTIFY toDateChanged REQUIRED)

public:
    enum Roles {
        NameRole = Qt::UserRole,
        TimelineRole,
    };

    explicit TimelineListModel(QObject *parent = nullptr);
    ~TimelineListModel() override;

    QVariant headerData(int section,
                        Qt::Orientation orientation,
                        int role = Qt::DisplayRole) const override;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
    QHash<int, QByteArray> roleNames() const override;

    void clear();

    QDate fromDate() const;
    void setFromDate(QDate date);

    QDate toDate() const;
    void setToDate(QDate date);

signals:
    void fromDateChanged(QDate date);
    void toDateChanged(QDate date);

private:
    Q_DISABLE_COPY_MOVE(TimelineListModel)

    struct Item;

    QModelIndex findIndexById(int id);
    void refill();

    QList<Item *> m_items;
    QDate m_fromDate;
    QDate m_toDate;
};

#endif // TIMELINELISTMODEL_H
